@@ -7,8 +7,8 @@ except ImportError:
 from django.contrib.auth import views as auth_views
 
 from shortcuts import route
-from views.client_views import login, show_login
-from views.client_views import new_identity, register
+from views import login, show_login
+from views import new_identity, register
 from forms import IdentityAuthenticationForm, RegistrationForm
 
 urlpatterns = patterns('identity_client.views',
